@@ -62,15 +62,14 @@ eif <- function(r, tau, shifted, natural) {
   natural[is.na(natural)] <- -999
   shifted[is.na(shifted)] <- -999
   m <- shifted[, 2:(tau + 1), drop = FALSE] - natural[, 1:tau, drop = FALSE]
-  rowSums(r * m, na.rm = TRUE) + shifted[, 1]
+  rowSums(compute_weights(r, 1, tau) * m, na.rm = TRUE) + shifted[, 1]
 }
 
 theta_dr <- function(eta, augmented = FALSE) {
-  inflnce <- eif(
-    r = eta$r, tau = eta$tau,
-    shifted = eta$m$shifted,
-    natural = eta$m$natural
-  )
+  inflnce <- eif(r = eta$r,
+                 tau = eta$tau,
+                 shifted = eta$m$shifted,
+                 natural = eta$m$natural)
 
   theta <- {
     if (augmented)
